export declare type ThrottledAggregation<T, R> = (id: T) => Promise<R>;
/**
 * Make a throttled aggregation function.
 *
 * Note: the `id` should be a primitive value, typically a string or a number.
 * If the `id` must be an array or an object, encode it in JSON.
 *
 * @param namespace Should be unique for each purpose.
 * @param request Accept ids, fire request and return the promise.
 * @param select Select the specific data for a specific id in the aggregated result.
 * @param wait Throttle wait time in milliseconds, defaults to 100.
 */
export declare function makeThrottledAggregation<T extends string | number, S, R>(namespace: string, request: (ids: T[]) => Promise<S>, select: (result: S, id: T) => R, wait?: number): ThrottledAggregation<T, R>;
