import { Node, SourceLocation, PipeCall } from "@next-core/pipes";
export declare enum LexicalStatus {
    Initial = 0,
    ExpectField = 1,
    ExpectOptionalBeginDefault = 2,
    ExpectDefaultValue = 3,
    ExpectOptionalBeginPipe = 4,
    ExpectPipeIdentifier = 5,
    ExpectOptionalBeginPipeParameter = 6,
    ExpectPipeParameter = 7,
    ExpectPlaceholderEnd = 8
}
export declare enum TokenType {
    Raw = "Raw",
    BeginPlaceHolder = "BeginPlaceHolder",
    Field = "Field",
    BeginDefault = "BeginDefault",
    LiteralString = "LiteralString",
    BeginPipe = "BeginPipe",
    PipeIdentifier = "PipeIdentifier",
    BeginPipeParameter = "BeginPipeParameter",
    EndPlaceHolder = "EndPlaceHolder",
    JsonValue = "JsonValue"
}
export declare enum JsonValueType {
    Array = 0,
    Object = 1,
    String = 2,
    Others = 3
}
export interface LexicalContext {
    beginPlaceholder: RegExp;
    raw: string;
    cursor: number;
    status: LexicalStatus;
    tokens: Token[];
}
export interface Token {
    type: TokenType;
    value?: any;
    loc?: SourceLocation;
}
export interface InjectableString extends Node {
    type: "InjectableString";
    elements: (RawString | Placeholder)[];
}
export interface RawString extends Node {
    type: "RawString";
    value: string;
}
export interface Placeholder extends Node {
    type: "Placeholder";
    symbol: string;
    field: string;
    defaultValue: any;
    pipes: PipeCall[];
}
