/**
 * Get smart display for a string property, which may be an evaluation.
 *
 * This is useful for brick editors to display specific property configurations.
 *
 * E.g., for a button brick editor, display it by
 * `smartDisplayForEvaluableString(btn.$$parsedProperties.buttonName, btn.alias, "<% … %>")`.
 *
 * @param rawString - Raw string value.
 * @param nonStringFallback - Fallback value if it's not a string.
 * @param unknownEvaluationFallback - Fallback value if it's an unknown evaluation.
 *
 * @returns
 *
 * Returns the nonStringFallback if the input is not a string and nonStringFallback presents.
 *
 * Or returns the raw input when nonStringFallback no presents.
 *
 * Returns the I18N default value (or key if no value found)
 * if it is an evaluation and contains one and only one I18N key.
 *
 * Or returns the unknownEvaluationFallback if it is an unknown evaluation string and
 * unknownEvaluationFallback presents.
 *
 * Or returns the raw input otherwise.
 */
export declare function smartDisplayForEvaluableString<T, U, V>(rawString: T, nonStringFallback?: U, unknownEvaluationFallback?: V): T | U | V | string;
