/**
 * Get tracking CTX for an evaluable expression in `track context` mode.
 *
 * A `track context` mode is an evaluable expression which is a sequence expression
 * starting with the exact literal string expression of "track context".
 *
 * @param raw - A raw string, which must be checked by `isEvaluable` first.
 *
 * @returns
 *
 * Returns used CTXs if `track context` mode is enabled, or returns false if not enabled or
 * no CTX found.
 *
 * @example
 *
 * ```js
 * trackContext('<% "track context", [CTX.hello, CTX.world] %>');
 * // => ["hello", "world"]
 *
 * trackContext('<% [CTX.hello, CTX.world] %>');
 * // => false
 *
 * trackContext('<% "track context", DATA.any %>');
 * // => false
 * ```
 */
export declare function trackContext(raw: string): string[] | false;
export declare function trackState(raw: string): string[] | false;
export declare function trackFormState(raw: string): string[] | false;
export declare function trackUsedContext(data: unknown): string[];
export declare function trackUsedState(data: unknown): string[];
export declare function trackUsedFormState(data: unknown): string[];
interface trackAllResult {
    context: string[] | false;
    state: string[] | false;
    formState: string[] | false;
}
export declare function trackAll(raw: string): trackAllResult | false;
export interface ContextUsage {
    usedContexts: string[];
    includesComputed: boolean;
}
export declare function collectContextUsage(data: unknown, variableName: string): ContextUsage;
export {};
